@@ -12,11 +12,11 @@ use warnings;
 use XML::LibXML;
 
 use vars qw ($VERSION);
-$VERSION = "2.0107"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "2.0109"; # VERSION TEMPLATE: DO NOT CHANGE
 
 use 5.008_000;
 
-use base qw(Exporter);
+use parent qw(Exporter);
 
 use vars qw( @EXPORT @EXPORT_OK %EXPORT_TAGS );
 
